# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroupAdServiceAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_type': 'AdGroupAdServiceAdType',
        'banner_image_ad': 'AdGroupAdServiceBannerImageAd',
        'banner_video_ad': 'AdGroupAdServiceBannerVideoAd',
        'dynamic_ad': 'AdGroupAdServiceDynamicAd',
        'mobile_ad': 'AdGroupAdServiceMobileAd',
        'pos_ad': 'AdGroupAdServicePosAd',
        'responsive_image_ad': 'AdGroupAdServiceResponsiveImageAd',
        'responsive_video_ad': 'AdGroupAdServiceResponsiveVideoAd',
        'static_frame_ad': 'AdGroupAdServiceStaticFrameAd',
        'text_ad': 'AdGroupAdServiceTextAd'
    }

    attribute_map = {
        'ad_type': 'adType',
        'banner_image_ad': 'bannerImageAd',
        'banner_video_ad': 'bannerVideoAd',
        'dynamic_ad': 'dynamicAd',
        'mobile_ad': 'mobileAd',
        'pos_ad': 'posAd',
        'responsive_image_ad': 'responsiveImageAd',
        'responsive_video_ad': 'responsiveVideoAd',
        'static_frame_ad': 'staticFrameAd',
        'text_ad': 'textAd'
    }

    def __init__(self, ad_type=None, banner_image_ad=None, banner_video_ad=None, dynamic_ad=None, mobile_ad=None, pos_ad=None, responsive_image_ad=None, responsive_video_ad=None, static_frame_ad=None, text_ad=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ad_type = None
        self._banner_image_ad = None
        self._banner_video_ad = None
        self._dynamic_ad = None
        self._mobile_ad = None
        self._pos_ad = None
        self._responsive_image_ad = None
        self._responsive_video_ad = None
        self._static_frame_ad = None
        self._text_ad = None
        self.discriminator = None

        self.ad_type = ad_type
        self.banner_image_ad = banner_image_ad
        self.banner_video_ad = banner_video_ad
        self.dynamic_ad = dynamic_ad
        self.mobile_ad = mobile_ad
        self.pos_ad = pos_ad
        self.responsive_image_ad = responsive_image_ad
        self.responsive_video_ad = responsive_video_ad
        self.static_frame_ad = static_frame_ad
        self.text_ad = text_ad

    @property
    def ad_type(self):
        """Gets the ad_type of this AdGroupAdServiceAd.  # noqa: E501


        :return: The ad_type of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceAdType
        """
        return self._ad_type

    @ad_type.setter
    def ad_type(self, ad_type):
        """Sets the ad_type of this AdGroupAdServiceAd.


        :param ad_type: The ad_type of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceAdType
        """

        self._ad_type = ad_type

    @property
    def banner_image_ad(self):
        """Gets the banner_image_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The banner_image_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceBannerImageAd
        """
        return self._banner_image_ad

    @banner_image_ad.setter
    def banner_image_ad(self, banner_image_ad):
        """Sets the banner_image_ad of this AdGroupAdServiceAd.


        :param banner_image_ad: The banner_image_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceBannerImageAd
        """

        self._banner_image_ad = banner_image_ad

    @property
    def banner_video_ad(self):
        """Gets the banner_video_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The banner_video_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceBannerVideoAd
        """
        return self._banner_video_ad

    @banner_video_ad.setter
    def banner_video_ad(self, banner_video_ad):
        """Sets the banner_video_ad of this AdGroupAdServiceAd.


        :param banner_video_ad: The banner_video_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceBannerVideoAd
        """

        self._banner_video_ad = banner_video_ad

    @property
    def dynamic_ad(self):
        """Gets the dynamic_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The dynamic_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceDynamicAd
        """
        return self._dynamic_ad

    @dynamic_ad.setter
    def dynamic_ad(self, dynamic_ad):
        """Sets the dynamic_ad of this AdGroupAdServiceAd.


        :param dynamic_ad: The dynamic_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceDynamicAd
        """

        self._dynamic_ad = dynamic_ad

    @property
    def mobile_ad(self):
        """Gets the mobile_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The mobile_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceMobileAd
        """
        return self._mobile_ad

    @mobile_ad.setter
    def mobile_ad(self, mobile_ad):
        """Sets the mobile_ad of this AdGroupAdServiceAd.


        :param mobile_ad: The mobile_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceMobileAd
        """

        self._mobile_ad = mobile_ad

    @property
    def pos_ad(self):
        """Gets the pos_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The pos_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServicePosAd
        """
        return self._pos_ad

    @pos_ad.setter
    def pos_ad(self, pos_ad):
        """Sets the pos_ad of this AdGroupAdServiceAd.


        :param pos_ad: The pos_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServicePosAd
        """

        self._pos_ad = pos_ad

    @property
    def responsive_image_ad(self):
        """Gets the responsive_image_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The responsive_image_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceResponsiveImageAd
        """
        return self._responsive_image_ad

    @responsive_image_ad.setter
    def responsive_image_ad(self, responsive_image_ad):
        """Sets the responsive_image_ad of this AdGroupAdServiceAd.


        :param responsive_image_ad: The responsive_image_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceResponsiveImageAd
        """

        self._responsive_image_ad = responsive_image_ad

    @property
    def responsive_video_ad(self):
        """Gets the responsive_video_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The responsive_video_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceResponsiveVideoAd
        """
        return self._responsive_video_ad

    @responsive_video_ad.setter
    def responsive_video_ad(self, responsive_video_ad):
        """Sets the responsive_video_ad of this AdGroupAdServiceAd.


        :param responsive_video_ad: The responsive_video_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceResponsiveVideoAd
        """

        self._responsive_video_ad = responsive_video_ad

    @property
    def static_frame_ad(self):
        """Gets the static_frame_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The static_frame_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceStaticFrameAd
        """
        return self._static_frame_ad

    @static_frame_ad.setter
    def static_frame_ad(self, static_frame_ad):
        """Sets the static_frame_ad of this AdGroupAdServiceAd.


        :param static_frame_ad: The static_frame_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceStaticFrameAd
        """

        self._static_frame_ad = static_frame_ad

    @property
    def text_ad(self):
        """Gets the text_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The text_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceTextAd
        """
        return self._text_ad

    @text_ad.setter
    def text_ad(self, text_ad):
        """Sets the text_ad of this AdGroupAdServiceAd.


        :param text_ad: The text_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceTextAd
        """

        self._text_ad = text_ad

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class FeedItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'availability': 'FeedItemServiceAvailability',
        'capacity': 'int',
        'display_settings': 'int',
        'feed_id': 'int',
        'formatted_price': 'str',
        'formatted_sale_price': 'str',
        'in_stock': 'int',
        'is_remove_capacity': 'FeedItemServiceIsRemoveFlg',
        'is_remove_formatted_price': 'FeedItemServiceIsRemoveFlg',
        'is_remove_formatted_sale_price': 'FeedItemServiceIsRemoveFlg',
        'is_remove_price': 'FeedItemServiceIsRemoveFlg',
        'is_remove_sale_price': 'FeedItemServiceIsRemoveFlg',
        'item_id': 'str',
        'price': 'int',
        'sale_price': 'int'
    }

    attribute_map = {
        'availability': 'availability',
        'capacity': 'capacity',
        'display_settings': 'displaySettings',
        'feed_id': 'feedId',
        'formatted_price': 'formattedPrice',
        'formatted_sale_price': 'formattedSalePrice',
        'in_stock': 'inStock',
        'is_remove_capacity': 'isRemoveCapacity',
        'is_remove_formatted_price': 'isRemoveFormattedPrice',
        'is_remove_formatted_sale_price': 'isRemoveFormattedSalePrice',
        'is_remove_price': 'isRemovePrice',
        'is_remove_sale_price': 'isRemoveSalePrice',
        'item_id': 'itemId',
        'price': 'price',
        'sale_price': 'salePrice'
    }

    def __init__(self, availability=None, capacity=None, display_settings=None, feed_id=None, formatted_price=None, formatted_sale_price=None, in_stock=None, is_remove_capacity=None, is_remove_formatted_price=None, is_remove_formatted_sale_price=None, is_remove_price=None, is_remove_sale_price=None, item_id=None, price=None, sale_price=None, local_vars_configuration=None):  # noqa: E501
        """FeedItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._availability = None
        self._capacity = None
        self._display_settings = None
        self._feed_id = None
        self._formatted_price = None
        self._formatted_sale_price = None
        self._in_stock = None
        self._is_remove_capacity = None
        self._is_remove_formatted_price = None
        self._is_remove_formatted_sale_price = None
        self._is_remove_price = None
        self._is_remove_sale_price = None
        self._item_id = None
        self._price = None
        self._sale_price = None
        self.discriminator = None

        self.availability = availability
        self.capacity = capacity
        self.display_settings = display_settings
        self.feed_id = feed_id
        self.formatted_price = formatted_price
        self.formatted_sale_price = formatted_sale_price
        self.in_stock = in_stock
        self.is_remove_capacity = is_remove_capacity
        self.is_remove_formatted_price = is_remove_formatted_price
        self.is_remove_formatted_sale_price = is_remove_formatted_sale_price
        self.is_remove_price = is_remove_price
        self.is_remove_sale_price = is_remove_sale_price
        self.item_id = item_id
        self.price = price
        self.sale_price = sale_price

    @property
    def availability(self):
        """Gets the availability of this FeedItem.  # noqa: E501


        :return: The availability of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceAvailability
        """
        return self._availability

    @availability.setter
    def availability(self, availability):
        """Sets the availability of this FeedItem.


        :param availability: The availability of this FeedItem.  # noqa: E501
        :type: FeedItemServiceAvailability
        """

        self._availability = availability

    @property
    def capacity(self):
        """Gets the capacity of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 在庫数です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Stock quantity.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The capacity of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this FeedItem.

        <div lang=\"ja\"> 在庫数です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Stock quantity.<br> This field is optional in requests. </div>   # noqa: E501

        :param capacity: The capacity of this FeedItem.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def display_settings(self):
        """Gets the display_settings of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 配信設定です。<br> このフィールドは、リクエストの場合は省略可能です。<br> ※「0:配信しない/1:配信する」を表します。 </div> <div lang=\"en\"> Display settings.<br> This field is optional in requests.<br> * 0: Off, 1: On. </div>   # noqa: E501

        :return: The display_settings of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._display_settings

    @display_settings.setter
    def display_settings(self, display_settings):
        """Sets the display_settings of this FeedItem.

        <div lang=\"ja\"> 配信設定です。<br> このフィールドは、リクエストの場合は省略可能です。<br> ※「0:配信しない/1:配信する」を表します。 </div> <div lang=\"en\"> Display settings.<br> This field is optional in requests.<br> * 0: Off, 1: On. </div>   # noqa: E501

        :param display_settings: The display_settings of this FeedItem.  # noqa: E501
        :type: int
        """

        self._display_settings = display_settings

    @property
    def feed_id(self):
        """Gets the feed_id of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> Feedを識別するIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> ID for identifying Feed.<br> This field is required in requests. </div>   # noqa: E501

        :return: The feed_id of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._feed_id

    @feed_id.setter
    def feed_id(self, feed_id):
        """Sets the feed_id of this FeedItem.

        <div lang=\"ja\"> Feedを識別するIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> ID for identifying Feed.<br> This field is required in requests. </div>   # noqa: E501

        :param feed_id: The feed_id of this FeedItem.  # noqa: E501
        :type: int
        """

        self._feed_id = feed_id

    @property
    def formatted_price(self):
        """Gets the formatted_price of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 文字列の価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Text strings price.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The formatted_price of this FeedItem.  # noqa: E501
        :rtype: str
        """
        return self._formatted_price

    @formatted_price.setter
    def formatted_price(self, formatted_price):
        """Sets the formatted_price of this FeedItem.

        <div lang=\"ja\"> 文字列の価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Text strings price.<br> This field is optional in requests. </div>   # noqa: E501

        :param formatted_price: The formatted_price of this FeedItem.  # noqa: E501
        :type: str
        """

        self._formatted_price = formatted_price

    @property
    def formatted_sale_price(self):
        """Gets the formatted_sale_price of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 文字列のセール価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Sale price of text strings.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The formatted_sale_price of this FeedItem.  # noqa: E501
        :rtype: str
        """
        return self._formatted_sale_price

    @formatted_sale_price.setter
    def formatted_sale_price(self, formatted_sale_price):
        """Sets the formatted_sale_price of this FeedItem.

        <div lang=\"ja\"> 文字列のセール価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Sale price of text strings.<br> This field is optional in requests. </div>   # noqa: E501

        :param formatted_sale_price: The formatted_sale_price of this FeedItem.  # noqa: E501
        :type: str
        """

        self._formatted_sale_price = formatted_sale_price

    @property
    def in_stock(self):
        """Gets the in_stock of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 在庫情報です。<br> このフィールドは、リクエストの場合は省略可能です。<br> ※「0:在庫なし/1:在庫あり」を表します。 </div> <div lang=\"en\"> Inventory information.<br> This field is optional in requests.<br> 0: Out of stock, 1: In stock. </div>   # noqa: E501

        :return: The in_stock of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._in_stock

    @in_stock.setter
    def in_stock(self, in_stock):
        """Sets the in_stock of this FeedItem.

        <div lang=\"ja\"> 在庫情報です。<br> このフィールドは、リクエストの場合は省略可能です。<br> ※「0:在庫なし/1:在庫あり」を表します。 </div> <div lang=\"en\"> Inventory information.<br> This field is optional in requests.<br> 0: Out of stock, 1: In stock. </div>   # noqa: E501

        :param in_stock: The in_stock of this FeedItem.  # noqa: E501
        :type: int
        """

        self._in_stock = in_stock

    @property
    def is_remove_capacity(self):
        """Gets the is_remove_capacity of this FeedItem.  # noqa: E501


        :return: The is_remove_capacity of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceIsRemoveFlg
        """
        return self._is_remove_capacity

    @is_remove_capacity.setter
    def is_remove_capacity(self, is_remove_capacity):
        """Sets the is_remove_capacity of this FeedItem.


        :param is_remove_capacity: The is_remove_capacity of this FeedItem.  # noqa: E501
        :type: FeedItemServiceIsRemoveFlg
        """

        self._is_remove_capacity = is_remove_capacity

    @property
    def is_remove_formatted_price(self):
        """Gets the is_remove_formatted_price of this FeedItem.  # noqa: E501


        :return: The is_remove_formatted_price of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceIsRemoveFlg
        """
        return self._is_remove_formatted_price

    @is_remove_formatted_price.setter
    def is_remove_formatted_price(self, is_remove_formatted_price):
        """Sets the is_remove_formatted_price of this FeedItem.


        :param is_remove_formatted_price: The is_remove_formatted_price of this FeedItem.  # noqa: E501
        :type: FeedItemServiceIsRemoveFlg
        """

        self._is_remove_formatted_price = is_remove_formatted_price

    @property
    def is_remove_formatted_sale_price(self):
        """Gets the is_remove_formatted_sale_price of this FeedItem.  # noqa: E501


        :return: The is_remove_formatted_sale_price of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceIsRemoveFlg
        """
        return self._is_remove_formatted_sale_price

    @is_remove_formatted_sale_price.setter
    def is_remove_formatted_sale_price(self, is_remove_formatted_sale_price):
        """Sets the is_remove_formatted_sale_price of this FeedItem.


        :param is_remove_formatted_sale_price: The is_remove_formatted_sale_price of this FeedItem.  # noqa: E501
        :type: FeedItemServiceIsRemoveFlg
        """

        self._is_remove_formatted_sale_price = is_remove_formatted_sale_price

    @property
    def is_remove_price(self):
        """Gets the is_remove_price of this FeedItem.  # noqa: E501


        :return: The is_remove_price of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceIsRemoveFlg
        """
        return self._is_remove_price

    @is_remove_price.setter
    def is_remove_price(self, is_remove_price):
        """Sets the is_remove_price of this FeedItem.


        :param is_remove_price: The is_remove_price of this FeedItem.  # noqa: E501
        :type: FeedItemServiceIsRemoveFlg
        """

        self._is_remove_price = is_remove_price

    @property
    def is_remove_sale_price(self):
        """Gets the is_remove_sale_price of this FeedItem.  # noqa: E501


        :return: The is_remove_sale_price of this FeedItem.  # noqa: E501
        :rtype: FeedItemServiceIsRemoveFlg
        """
        return self._is_remove_sale_price

    @is_remove_sale_price.setter
    def is_remove_sale_price(self, is_remove_sale_price):
        """Sets the is_remove_sale_price of this FeedItem.


        :param is_remove_sale_price: The is_remove_sale_price of this FeedItem.  # noqa: E501
        :type: FeedItemServiceIsRemoveFlg
        """

        self._is_remove_sale_price = is_remove_sale_price

    @property
    def item_id(self):
        """Gets the item_id of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 商品IDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Item ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The item_id of this FeedItem.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this FeedItem.

        <div lang=\"ja\"> 商品IDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Item ID.<br> This field is required in requests. </div>   # noqa: E501

        :param item_id: The item_id of this FeedItem.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def price(self):
        """Gets the price of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> 価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Price.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The price of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this FeedItem.

        <div lang=\"ja\"> 価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Price.<br> This field is optional in requests. </div>   # noqa: E501

        :param price: The price of this FeedItem.  # noqa: E501
        :type: int
        """

        self._price = price

    @property
    def sale_price(self):
        """Gets the sale_price of this FeedItem.  # noqa: E501

        <div lang=\"ja\"> セール価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Sale price.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The sale_price of this FeedItem.  # noqa: E501
        :rtype: int
        """
        return self._sale_price

    @sale_price.setter
    def sale_price(self, sale_price):
        """Sets the sale_price of this FeedItem.

        <div lang=\"ja\"> セール価格です。<br> このフィールドは、リクエストの場合は省略可能です。 </div> <div lang=\"en\"> Sale price.<br> This field is optional in requests. </div>   # noqa: E501

        :param sale_price: The sale_price of this FeedItem.  # noqa: E501
        :type: int
        """

        self._sale_price = sale_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class DictionaryServiceMediaAdFormat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_format': 'str',
        'aspect': 'bool',
        'aspect_height': 'int',
        'aspect_ratio': 'str',
        'aspect_width': 'int',
        'campaign_banner': 'bool',
        'height': 'int',
        'logo': 'bool',
        'max_height': 'int',
        'max_width': 'int',
        'size': 'int',
        'size_to': 'int',
        'static_image': 'bool',
        'thumbnail': 'bool',
        'transparent': 'bool',
        'width': 'int'
    }

    attribute_map = {
        'ad_format': 'adFormat',
        'aspect': 'aspect',
        'aspect_height': 'aspectHeight',
        'aspect_ratio': 'aspectRatio',
        'aspect_width': 'aspectWidth',
        'campaign_banner': 'campaignBanner',
        'height': 'height',
        'logo': 'logo',
        'max_height': 'maxHeight',
        'max_width': 'maxWidth',
        'size': 'size',
        'size_to': 'sizeTo',
        'static_image': 'staticImage',
        'thumbnail': 'thumbnail',
        'transparent': 'transparent',
        'width': 'width'
    }

    def __init__(self, ad_format=None, aspect=None, aspect_height=None, aspect_ratio=None, aspect_width=None, campaign_banner=None, height=None, logo=None, max_height=None, max_width=None, size=None, size_to=None, static_image=None, thumbnail=None, transparent=None, width=None, local_vars_configuration=None):  # noqa: E501
        """DictionaryServiceMediaAdFormat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ad_format = None
        self._aspect = None
        self._aspect_height = None
        self._aspect_ratio = None
        self._aspect_width = None
        self._campaign_banner = None
        self._height = None
        self._logo = None
        self._max_height = None
        self._max_width = None
        self._size = None
        self._size_to = None
        self._static_image = None
        self._thumbnail = None
        self._transparent = None
        self._width = None
        self.discriminator = None

        self.ad_format = ad_format
        self.aspect = aspect
        self.aspect_height = aspect_height
        self.aspect_ratio = aspect_ratio
        self.aspect_width = aspect_width
        self.campaign_banner = campaign_banner
        self.height = height
        self.logo = logo
        self.max_height = max_height
        self.max_width = max_width
        self.size = size
        self.size_to = size_to
        self.static_image = static_image
        self.thumbnail = thumbnail
        self.transparent = transparent
        self.width = width

    @property
    def ad_format(self):
        """Gets the ad_format of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">ディスプレイ（画像）広告のフォーマットです。</div> <div lang=\"en\">Format of display (image) ads</div>   # noqa: E501

        :return: The ad_format of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: str
        """
        return self._ad_format

    @ad_format.setter
    def ad_format(self, ad_format):
        """Sets the ad_format of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">ディスプレイ（画像）広告のフォーマットです。</div> <div lang=\"en\">Format of display (image) ads</div>   # noqa: E501

        :param ad_format: The ad_format of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: str
        """

        self._ad_format = ad_format

    @property
    def aspect(self):
        """Gets the aspect of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">アスペクト比対応かどうかを示します。</div> <div lang=\"en\">This field indicates whether the aspect ratio is supported.</div>   # noqa: E501

        :return: The aspect of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">アスペクト比対応かどうかを示します。</div> <div lang=\"en\">This field indicates whether the aspect ratio is supported.</div>   # noqa: E501

        :param aspect: The aspect of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._aspect = aspect

    @property
    def aspect_height(self):
        """Gets the aspect_height of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">画像アスペクト比：高さ [ratio]です。</div> <div lang=\"en\">Image aspect ratio: height [ratio]</div>   # noqa: E501

        :return: The aspect_height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._aspect_height

    @aspect_height.setter
    def aspect_height(self, aspect_height):
        """Sets the aspect_height of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">画像アスペクト比：高さ [ratio]です。</div> <div lang=\"en\">Image aspect ratio: height [ratio]</div>   # noqa: E501

        :param aspect_height: The aspect_height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._aspect_height = aspect_height

    @property
    def aspect_ratio(self):
        """Gets the aspect_ratio of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">アスペクト比です。</div> <div lang=\"en\">Aspect ratio.</div>   # noqa: E501

        :return: The aspect_ratio of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: str
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        """Sets the aspect_ratio of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">アスペクト比です。</div> <div lang=\"en\">Aspect ratio.</div>   # noqa: E501

        :param aspect_ratio: The aspect_ratio of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: str
        """

        self._aspect_ratio = aspect_ratio

    @property
    def aspect_width(self):
        """Gets the aspect_width of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">画像アスペクト比：幅 [ratio]です。</div> <div lang=\"en\">Image aspect ratio: width [ratio]</div>   # noqa: E501

        :return: The aspect_width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._aspect_width

    @aspect_width.setter
    def aspect_width(self, aspect_width):
        """Sets the aspect_width of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">画像アスペクト比：幅 [ratio]です。</div> <div lang=\"en\">Image aspect ratio: width [ratio]</div>   # noqa: E501

        :param aspect_width: The aspect_width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._aspect_width = aspect_width

    @property
    def campaign_banner(self):
        """Gets the campaign_banner of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">キャンペーンバナー画像である/キャンペーンバナー画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a campaign banner image or not.</div>   # noqa: E501

        :return: The campaign_banner of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._campaign_banner

    @campaign_banner.setter
    def campaign_banner(self, campaign_banner):
        """Sets the campaign_banner of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">キャンペーンバナー画像である/キャンペーンバナー画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a campaign banner image or not.</div>   # noqa: E501

        :param campaign_banner: The campaign_banner of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._campaign_banner = campaign_banner

    @property
    def height(self):
        """Gets the height of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">最小画像サイズ：高さ [pixel]です。</div> <div lang=\"en\">Minimum image size: height [pixel]</div>   # noqa: E501

        :return: The height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">最小画像サイズ：高さ [pixel]です。</div> <div lang=\"en\">Minimum image size: height [pixel]</div>   # noqa: E501

        :param height: The height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def logo(self):
        """Gets the logo of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">ロゴ画像である/ロゴ画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a logo image or not.</div>   # noqa: E501

        :return: The logo of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">ロゴ画像である/ロゴ画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a logo image or not.</div>   # noqa: E501

        :param logo: The logo of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._logo = logo

    @property
    def max_height(self):
        """Gets the max_height of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">サイズ上限：高さ [pixel]です。</div> <div lang=\"en\">Size limit: height [pixel]</div>   # noqa: E501

        :return: The max_height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._max_height

    @max_height.setter
    def max_height(self, max_height):
        """Sets the max_height of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">サイズ上限：高さ [pixel]です。</div> <div lang=\"en\">Size limit: height [pixel]</div>   # noqa: E501

        :param max_height: The max_height of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._max_height = max_height

    @property
    def max_width(self):
        """Gets the max_width of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">サイズ上限：幅 [pixel]です。</div> <div lang=\"en\">Size limit: width [pixel]</div>   # noqa: E501

        :return: The max_width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._max_width

    @max_width.setter
    def max_width(self, max_width):
        """Sets the max_width of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">サイズ上限：幅 [pixel]です。</div> <div lang=\"en\">Size limit: width [pixel]</div>   # noqa: E501

        :param max_width: The max_width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._max_width = max_width

    @property
    def size(self):
        """Gets the size of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">画像の最大容量：[byte]です。</div> <div lang=\"en\">Maximum image capacity: [byte]</div>   # noqa: E501

        :return: The size of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">画像の最大容量：[byte]です。</div> <div lang=\"en\">Maximum image capacity: [byte]</div>   # noqa: E501

        :param size: The size of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def size_to(self):
        """Gets the size_to of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">画像圧縮後の容量：[byte]です。</div> <div lang=\"en\">Image compression capacity: [byte]</div>   # noqa: E501

        :return: The size_to of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._size_to

    @size_to.setter
    def size_to(self, size_to):
        """Sets the size_to of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">画像圧縮後の容量：[byte]です。</div> <div lang=\"en\">Image compression capacity: [byte]</div>   # noqa: E501

        :param size_to: The size_to of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._size_to = size_to

    @property
    def static_image(self):
        """Gets the static_image of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">静止画用の画像かどうかを示します。</div> <div lang=\"en\">This field indicates whether it is a static image.</div>   # noqa: E501

        :return: The static_image of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._static_image

    @static_image.setter
    def static_image(self, static_image):
        """Sets the static_image of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">静止画用の画像かどうかを示します。</div> <div lang=\"en\">This field indicates whether it is a static image.</div>   # noqa: E501

        :param static_image: The static_image of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._static_image = static_image

    @property
    def thumbnail(self):
        """Gets the thumbnail of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">サムネイル画像である/サムネイル画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a thumbnail image image or not.</div>   # noqa: E501

        :return: The thumbnail of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">サムネイル画像である/サムネイル画像ではないことを示します。</div> <div lang=\"en\">This field indicates whether it is a thumbnail image image or not.</div>   # noqa: E501

        :param thumbnail: The thumbnail of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._thumbnail = thumbnail

    @property
    def transparent(self):
        """Gets the transparent of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">透過画像の許可/不許可を示します。</div> <div lang=\"en\">This field indicates whether transparent image is permitted.</div>   # noqa: E501

        :return: The transparent of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: bool
        """
        return self._transparent

    @transparent.setter
    def transparent(self, transparent):
        """Sets the transparent of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">透過画像の許可/不許可を示します。</div> <div lang=\"en\">This field indicates whether transparent image is permitted.</div>   # noqa: E501

        :param transparent: The transparent of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: bool
        """

        self._transparent = transparent

    @property
    def width(self):
        """Gets the width of this DictionaryServiceMediaAdFormat.  # noqa: E501

        <div lang=\"ja\">最小画像サイズ：幅 [pixel]です。</div> <div lang=\"en\">Minimum image size: width [pixel]</div>   # noqa: E501

        :return: The width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DictionaryServiceMediaAdFormat.

        <div lang=\"ja\">最小画像サイズ：幅 [pixel]です。</div> <div lang=\"en\">Minimum image size: width [pixel]</div>   # noqa: E501

        :param width: The width of this DictionaryServiceMediaAdFormat.  # noqa: E501
        :type: int
        """

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DictionaryServiceMediaAdFormat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DictionaryServiceMediaAdFormat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class VideoServiceSetting(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file_size': 'int',
        'file_type': 'VideoServiceFileType',
        'height': 'int',
        'playback_time': 'int',
        'video_ad_format': 'str',
        'video_aspect_ratio': 'str',
        'width': 'int'
    }

    attribute_map = {
        'file_size': 'fileSize',
        'file_type': 'fileType',
        'height': 'height',
        'playback_time': 'playbackTime',
        'video_ad_format': 'videoAdFormat',
        'video_aspect_ratio': 'videoAspectRatio',
        'width': 'width'
    }

    def __init__(self, file_size=None, file_type=None, height=None, playback_time=None, video_ad_format=None, video_aspect_ratio=None, width=None, local_vars_configuration=None):  # noqa: E501
        """VideoServiceSetting - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file_size = None
        self._file_type = None
        self._height = None
        self._playback_time = None
        self._video_ad_format = None
        self._video_aspect_ratio = None
        self._width = None
        self.discriminator = None

        self.file_size = file_size
        self.file_type = file_type
        self.height = height
        self.playback_time = playback_time
        self.video_ad_format = video_ad_format
        self.video_aspect_ratio = video_aspect_ratio
        self.width = width

    @property
    def file_size(self):
        """Gets the file_size of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\">動画のファイルサイズです。</div> <div lang=\"en\">File size of the video.</div>   # noqa: E501

        :return: The file_size of this VideoServiceSetting.  # noqa: E501
        :rtype: int
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """Sets the file_size of this VideoServiceSetting.

        <div lang=\"ja\">動画のファイルサイズです。</div> <div lang=\"en\">File size of the video.</div>   # noqa: E501

        :param file_size: The file_size of this VideoServiceSetting.  # noqa: E501
        :type: int
        """

        self._file_size = file_size

    @property
    def file_type(self):
        """Gets the file_type of this VideoServiceSetting.  # noqa: E501


        :return: The file_type of this VideoServiceSetting.  # noqa: E501
        :rtype: VideoServiceFileType
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this VideoServiceSetting.


        :param file_type: The file_type of this VideoServiceSetting.  # noqa: E501
        :type: VideoServiceFileType
        """

        self._file_type = file_type

    @property
    def height(self):
        """Gets the height of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\">動画の高さ（縦の長さ）です。</div> <div lang=\"en\">Height (vertical length) of the video.</div>   # noqa: E501

        :return: The height of this VideoServiceSetting.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this VideoServiceSetting.

        <div lang=\"ja\">動画の高さ（縦の長さ）です。</div> <div lang=\"en\">Height (vertical length) of the video.</div>   # noqa: E501

        :param height: The height of this VideoServiceSetting.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def playback_time(self):
        """Gets the playback_time of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\">動画再生時間（秒）です。</div> <div lang=\"en\">Play time (sec) of the video.</div>   # noqa: E501

        :return: The playback_time of this VideoServiceSetting.  # noqa: E501
        :rtype: int
        """
        return self._playback_time

    @playback_time.setter
    def playback_time(self, playback_time):
        """Sets the playback_time of this VideoServiceSetting.

        <div lang=\"ja\">動画再生時間（秒）です。</div> <div lang=\"en\">Play time (sec) of the video.</div>   # noqa: E501

        :param playback_time: The playback_time of this VideoServiceSetting.  # noqa: E501
        :type: int
        """

        self._playback_time = playback_time

    @property
    def video_ad_format(self):
        """Gets the video_ad_format of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\">動画広告の種類です。</div> <div lang=\"en\">Ad format type of the video ad.</div>   # noqa: E501

        :return: The video_ad_format of this VideoServiceSetting.  # noqa: E501
        :rtype: str
        """
        return self._video_ad_format

    @video_ad_format.setter
    def video_ad_format(self, video_ad_format):
        """Sets the video_ad_format of this VideoServiceSetting.

        <div lang=\"ja\">動画広告の種類です。</div> <div lang=\"en\">Ad format type of the video ad.</div>   # noqa: E501

        :param video_ad_format: The video_ad_format of this VideoServiceSetting.  # noqa: E501
        :type: str
        """

        self._video_ad_format = video_ad_format

    @property
    def video_aspect_ratio(self):
        """Gets the video_aspect_ratio of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\"> 動画アスペクト比の種類です。<br> ※指定可能な値は、DictionaryServiceのgetMediaAdFormatで取得されるDictionaryServiceMediaAdFormatのaspectRatioフィールドをご確認ください。 </div> <div lang=\"en\"> Type of aspect ratio.<br> * Available values can be referred to aspectRatio field of DictionaryServiceMediaAdFormat object obtained by getMediaAdFormat operation of DictionaryService. </div>   # noqa: E501

        :return: The video_aspect_ratio of this VideoServiceSetting.  # noqa: E501
        :rtype: str
        """
        return self._video_aspect_ratio

    @video_aspect_ratio.setter
    def video_aspect_ratio(self, video_aspect_ratio):
        """Sets the video_aspect_ratio of this VideoServiceSetting.

        <div lang=\"ja\"> 動画アスペクト比の種類です。<br> ※指定可能な値は、DictionaryServiceのgetMediaAdFormatで取得されるDictionaryServiceMediaAdFormatのaspectRatioフィールドをご確認ください。 </div> <div lang=\"en\"> Type of aspect ratio.<br> * Available values can be referred to aspectRatio field of DictionaryServiceMediaAdFormat object obtained by getMediaAdFormat operation of DictionaryService. </div>   # noqa: E501

        :param video_aspect_ratio: The video_aspect_ratio of this VideoServiceSetting.  # noqa: E501
        :type: str
        """

        self._video_aspect_ratio = video_aspect_ratio

    @property
    def width(self):
        """Gets the width of this VideoServiceSetting.  # noqa: E501

        <div lang=\"ja\">動画の横幅です。</div> <div lang=\"en\">Width of the video.</div>   # noqa: E501

        :return: The width of this VideoServiceSetting.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this VideoServiceSetting.

        <div lang=\"ja\">動画の横幅です。</div> <div lang=\"en\">Width of the video.</div>   # noqa: E501

        :param width: The width of this VideoServiceSetting.  # noqa: E501
        :type: int
        """

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoServiceSetting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoServiceSetting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class Campaign(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad_product_type': 'str',
        'app_id': 'str',
        'app_name': 'str',
        'bidding_strategy': 'CampaignServiceBiddingStrategy',
        'budget': 'CampaignServiceBudget',
        'campaign_bidding_strategy': 'CampaignServiceCampaignBiddingStrategy',
        'campaign_goal': 'str',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'conversion_optimizer': 'CampaignServiceConversionOptimizer',
        'device_os_type': 'CampaignServiceDeviceOsType',
        'end_date': 'str',
        'feed_id': 'int',
        'frequency_cap': 'CampaignServiceFrequencyCap',
        'labels': 'list[CampaignServiceLabel]',
        'serving_status': 'CampaignServiceServingStatus',
        'start_date': 'str',
        'type': 'CampaignServiceType',
        'user_status': 'CampaignServiceUserStatus',
        'viewable_frequency_cap': 'CampaignServiceViewableFrequencyCap'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad_product_type': 'adProductType',
        'app_id': 'appId',
        'app_name': 'appName',
        'bidding_strategy': 'biddingStrategy',
        'budget': 'budget',
        'campaign_bidding_strategy': 'campaignBiddingStrategy',
        'campaign_goal': 'campaignGoal',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'conversion_optimizer': 'conversionOptimizer',
        'device_os_type': 'deviceOsType',
        'end_date': 'endDate',
        'feed_id': 'feedId',
        'frequency_cap': 'frequencyCap',
        'labels': 'labels',
        'serving_status': 'servingStatus',
        'start_date': 'startDate',
        'type': 'type',
        'user_status': 'userStatus',
        'viewable_frequency_cap': 'viewableFrequencyCap'
    }

    def __init__(self, account_id=None, ad_product_type=None, app_id=None, app_name=None, bidding_strategy=None, budget=None, campaign_bidding_strategy=None, campaign_goal=None, campaign_id=None, campaign_name=None, conversion_optimizer=None, device_os_type=None, end_date=None, feed_id=None, frequency_cap=None, labels=None, serving_status=None, start_date=None, type=None, user_status=None, viewable_frequency_cap=None, local_vars_configuration=None):  # noqa: E501
        """Campaign - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad_product_type = None
        self._app_id = None
        self._app_name = None
        self._bidding_strategy = None
        self._budget = None
        self._campaign_bidding_strategy = None
        self._campaign_goal = None
        self._campaign_id = None
        self._campaign_name = None
        self._conversion_optimizer = None
        self._device_os_type = None
        self._end_date = None
        self._feed_id = None
        self._frequency_cap = None
        self._labels = None
        self._serving_status = None
        self._start_date = None
        self._type = None
        self._user_status = None
        self._viewable_frequency_cap = None
        self.discriminator = None

        self.account_id = account_id
        self.ad_product_type = ad_product_type
        self.app_id = app_id
        self.app_name = app_name
        self.bidding_strategy = bidding_strategy
        self.budget = budget
        self.campaign_bidding_strategy = campaign_bidding_strategy
        self.campaign_goal = campaign_goal
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.conversion_optimizer = conversion_optimizer
        self.device_os_type = device_os_type
        self.end_date = end_date
        self.feed_id = feed_id
        self.frequency_cap = frequency_cap
        self.labels = labels
        self.serving_status = serving_status
        self.start_date = start_date
        self.type = type
        self.user_status = user_status
        self.viewable_frequency_cap = viewable_frequency_cap

    @property
    def account_id(self):
        """Gets the account_id of this Campaign.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID. <br> This field is required in requests. </div>   # noqa: E501

        :return: The account_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Campaign.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID. <br> This field is required in requests. </div>   # noqa: E501

        :param account_id: The account_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def ad_product_type(self):
        """Gets the ad_product_type of this Campaign.  # noqa: E501

        <div lang=\"ja\"> 配信方法です。<br> ADD時、このフィールドは目的なしの場合は必須となり、目的ありの場合は設定不可となります。<br> REMOVE時、このフィールドは無視されます。<br> ※指定可能な値は、AccountAdProductServiceのGET操作で取得されるAdProductをご確認ください。 </div> <div lang=\"en\"> Ad product information.<br> In ADD operation, this field is required for campaigns with no campaign goal, and this field cannot be set for campaigns with campaign goal. <br> In REMOVE operation, this field will be ignored.<br> * Available values can be referred to adProductType field of AdProduct object obtained by GET operation of AccountAdProductService. </div>   # noqa: E501

        :return: The ad_product_type of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._ad_product_type

    @ad_product_type.setter
    def ad_product_type(self, ad_product_type):
        """Sets the ad_product_type of this Campaign.

        <div lang=\"ja\"> 配信方法です。<br> ADD時、このフィールドは目的なしの場合は必須となり、目的ありの場合は設定不可となります。<br> REMOVE時、このフィールドは無視されます。<br> ※指定可能な値は、AccountAdProductServiceのGET操作で取得されるAdProductをご確認ください。 </div> <div lang=\"en\"> Ad product information.<br> In ADD operation, this field is required for campaigns with no campaign goal, and this field cannot be set for campaigns with campaign goal. <br> In REMOVE operation, this field will be ignored.<br> * Available values can be referred to adProductType field of AdProduct object obtained by GET operation of AccountAdProductService. </div>   # noqa: E501

        :param ad_product_type: The ad_product_type of this Campaign.  # noqa: E501
        :type: str
        """

        self._ad_product_type = ad_product_type

    @property
    def app_id(self):
        """Gets the app_id of this Campaign.  # noqa: E501

        <div lang=\"ja\"> iOS:アプリIDです。<br> Android:パッケージ名です。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時は無視されます。<br> ※campaignTypeがAPPの場合、ADD時に必須となります。 </div> <div lang=\"en\"> iOS: APP ID.<br> Android: Package name. <br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation.<br> *If campaignType is APP, this field is required in ADD operation. </div>   # noqa: E501

        :return: The app_id of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this Campaign.

        <div lang=\"ja\"> iOS:アプリIDです。<br> Android:パッケージ名です。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時は無視されます。<br> ※campaignTypeがAPPの場合、ADD時に必須となります。 </div> <div lang=\"en\"> iOS: APP ID.<br> Android: Package name. <br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation.<br> *If campaignType is APP, this field is required in ADD operation. </div>   # noqa: E501

        :param app_id: The app_id of this Campaign.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def app_name(self):
        """Gets the app_name of this Campaign.  # noqa: E501

        <div lang=\"ja\"> アプリの名称です。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時は無視されます。<br> ※campaignTypeがAPPの場合、ADD時に必須となります。 </div> <div lang=\"en\"> App Name. <br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation.<br> *If campaignType is APP, this field is required in ADD operation. </div>   # noqa: E501

        :return: The app_name of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this Campaign.

        <div lang=\"ja\"> アプリの名称です。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時は無視されます。<br> ※campaignTypeがAPPの場合、ADD時に必須となります。 </div> <div lang=\"en\"> App Name. <br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation.<br> *If campaignType is APP, this field is required in ADD operation. </div>   # noqa: E501

        :param app_name: The app_name of this Campaign.  # noqa: E501
        :type: str
        """

        self._app_name = app_name

    @property
    def bidding_strategy(self):
        """Gets the bidding_strategy of this Campaign.  # noqa: E501


        :return: The bidding_strategy of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategy
        """
        return self._bidding_strategy

    @bidding_strategy.setter
    def bidding_strategy(self, bidding_strategy):
        """Sets the bidding_strategy of this Campaign.


        :param bidding_strategy: The bidding_strategy of this Campaign.  # noqa: E501
        :type: CampaignServiceBiddingStrategy
        """

        self._bidding_strategy = bidding_strategy

    @property
    def budget(self):
        """Gets the budget of this Campaign.  # noqa: E501


        :return: The budget of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBudget
        """
        return self._budget

    @budget.setter
    def budget(self, budget):
        """Sets the budget of this Campaign.


        :param budget: The budget of this Campaign.  # noqa: E501
        :type: CampaignServiceBudget
        """

        self._budget = budget

    @property
    def campaign_bidding_strategy(self):
        """Gets the campaign_bidding_strategy of this Campaign.  # noqa: E501


        :return: The campaign_bidding_strategy of this Campaign.  # noqa: E501
        :rtype: CampaignServiceCampaignBiddingStrategy
        """
        return self._campaign_bidding_strategy

    @campaign_bidding_strategy.setter
    def campaign_bidding_strategy(self, campaign_bidding_strategy):
        """Sets the campaign_bidding_strategy of this Campaign.


        :param campaign_bidding_strategy: The campaign_bidding_strategy of this Campaign.  # noqa: E501
        :type: CampaignServiceCampaignBiddingStrategy
        """

        self._campaign_bidding_strategy = campaign_bidding_strategy

    @property
    def campaign_goal(self):
        """Gets the campaign_goal of this Campaign.  # noqa: E501

        <div lang=\"ja\"> キャンペーン目的です。<br> ADD時、このフィールドは目的なしの場合は設定不可となり、目的ありの場合は必須となります。<br> SETおよびREMOVE時、このフィールドは無視されます。<br> ※指定可能な値は、AccountServiceのGET操作で得られるAccountのaccountAuthoritiesフィールドをご確認ください。<br> </div> <div lang=\"en\"> Campaign goal.<br> In ADD operation, this field cannot be set for campaigns with no campaign goal, and will be required for campaigns with campaign goal.<br> In SET and REMOVE operation, this field will be ignored.<br> * Available values can be referred to accountAuthorities field of Account object obtained by GET operation of AccountService.<br> </div>   # noqa: E501

        :return: The campaign_goal of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._campaign_goal

    @campaign_goal.setter
    def campaign_goal(self, campaign_goal):
        """Sets the campaign_goal of this Campaign.

        <div lang=\"ja\"> キャンペーン目的です。<br> ADD時、このフィールドは目的なしの場合は設定不可となり、目的ありの場合は必須となります。<br> SETおよびREMOVE時、このフィールドは無視されます。<br> ※指定可能な値は、AccountServiceのGET操作で得られるAccountのaccountAuthoritiesフィールドをご確認ください。<br> </div> <div lang=\"en\"> Campaign goal.<br> In ADD operation, this field cannot be set for campaigns with no campaign goal, and will be required for campaigns with campaign goal.<br> In SET and REMOVE operation, this field will be ignored.<br> * Available values can be referred to accountAuthorities field of Account object obtained by GET operation of AccountService.<br> </div>   # noqa: E501

        :param campaign_goal: The campaign_goal of this Campaign.  # noqa: E501
        :type: str
        """

        self._campaign_goal = campaign_goal

    @property
    def campaign_id(self):
        """Gets the campaign_id of this Campaign.  # noqa: E501

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドはSETおよびREMOVE時に必須となり、ADD時に無視されます。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in SET and REMOVE operation, and will be ignored in ADD operation. </div>   # noqa: E501

        :return: The campaign_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this Campaign.

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドはSETおよびREMOVE時に必須となり、ADD時に無視されます。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in SET and REMOVE operation, and will be ignored in ADD operation. </div>   # noqa: E501

        :param campaign_id: The campaign_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this Campaign.  # noqa: E501

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、ADD時は必須、SET時は省略可能となり、REMOVE時は無視されます。 </div> <div lang=\"en\"> Campaign Name.<br> This field is required in ADD operation, is optional in SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :return: The campaign_name of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this Campaign.

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、ADD時は必須、SET時は省略可能となり、REMOVE時は無視されます。 </div> <div lang=\"en\"> Campaign Name.<br> This field is required in ADD operation, is optional in SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :param campaign_name: The campaign_name of this Campaign.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def conversion_optimizer(self):
        """Gets the conversion_optimizer of this Campaign.  # noqa: E501


        :return: The conversion_optimizer of this Campaign.  # noqa: E501
        :rtype: CampaignServiceConversionOptimizer
        """
        return self._conversion_optimizer

    @conversion_optimizer.setter
    def conversion_optimizer(self, conversion_optimizer):
        """Sets the conversion_optimizer of this Campaign.


        :param conversion_optimizer: The conversion_optimizer of this Campaign.  # noqa: E501
        :type: CampaignServiceConversionOptimizer
        """

        self._conversion_optimizer = conversion_optimizer

    @property
    def device_os_type(self):
        """Gets the device_os_type of this Campaign.  # noqa: E501


        :return: The device_os_type of this Campaign.  # noqa: E501
        :rtype: CampaignServiceDeviceOsType
        """
        return self._device_os_type

    @device_os_type.setter
    def device_os_type(self, device_os_type):
        """Sets the device_os_type of this Campaign.


        :param device_os_type: The device_os_type of this Campaign.  # noqa: E501
        :type: CampaignServiceDeviceOsType
        """

        self._device_os_type = device_os_type

    @property
    def end_date(self):
        """Gets the end_date of this Campaign.  # noqa: E501

        <div lang=\"ja\"> 終了日です。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> End date.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :return: The end_date of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Campaign.

        <div lang=\"ja\"> 終了日です。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> End date.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :param end_date: The end_date of this Campaign.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def feed_id(self):
        """Gets the feed_id of this Campaign.  # noqa: E501

        <div lang=\"ja\"> フィードIDです。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時に無視されます。<br> ※動的ディスプレイ広告の場合、ADD時に必須となります。 </div> <div lang=\"en\"> Feed ID.<br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation. <br> *If adType is Dynamic Ads for Display, this field is required in ADD operation. </div>   # noqa: E501

        :return: The feed_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._feed_id

    @feed_id.setter
    def feed_id(self, feed_id):
        """Sets the feed_id of this Campaign.

        <div lang=\"ja\"> フィードIDです。<br> このフィールドは、ADD時に省略可能となり、SETおよびREMOVE時に無視されます。<br> ※動的ディスプレイ広告の場合、ADD時に必須となります。 </div> <div lang=\"en\"> Feed ID.<br> This field is optional in ADD operation, and will be ignored in SET and REMOVE operation. <br> *If adType is Dynamic Ads for Display, this field is required in ADD operation. </div>   # noqa: E501

        :param feed_id: The feed_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._feed_id = feed_id

    @property
    def frequency_cap(self):
        """Gets the frequency_cap of this Campaign.  # noqa: E501


        :return: The frequency_cap of this Campaign.  # noqa: E501
        :rtype: CampaignServiceFrequencyCap
        """
        return self._frequency_cap

    @frequency_cap.setter
    def frequency_cap(self, frequency_cap):
        """Sets the frequency_cap of this Campaign.


        :param frequency_cap: The frequency_cap of this Campaign.  # noqa: E501
        :type: CampaignServiceFrequencyCap
        """

        self._frequency_cap = frequency_cap

    @property
    def labels(self):
        """Gets the labels of this Campaign.  # noqa: E501


        :return: The labels of this Campaign.  # noqa: E501
        :rtype: list[CampaignServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Campaign.


        :param labels: The labels of this Campaign.  # noqa: E501
        :type: list[CampaignServiceLabel]
        """

        self._labels = labels

    @property
    def serving_status(self):
        """Gets the serving_status of this Campaign.  # noqa: E501


        :return: The serving_status of this Campaign.  # noqa: E501
        :rtype: CampaignServiceServingStatus
        """
        return self._serving_status

    @serving_status.setter
    def serving_status(self, serving_status):
        """Sets the serving_status of this Campaign.


        :param serving_status: The serving_status of this Campaign.  # noqa: E501
        :type: CampaignServiceServingStatus
        """

        self._serving_status = serving_status

    @property
    def start_date(self):
        """Gets the start_date of this Campaign.  # noqa: E501

        <div lang=\"ja\"> 開始日です。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> Start date.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :return: The start_date of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Campaign.

        <div lang=\"ja\"> 開始日です。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> Start date.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :param start_date: The start_date of this Campaign.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def type(self):
        """Gets the type of this Campaign.  # noqa: E501


        :return: The type of this Campaign.  # noqa: E501
        :rtype: CampaignServiceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Campaign.


        :param type: The type of this Campaign.  # noqa: E501
        :type: CampaignServiceType
        """

        self._type = type

    @property
    def user_status(self):
        """Gets the user_status of this Campaign.  # noqa: E501


        :return: The user_status of this Campaign.  # noqa: E501
        :rtype: CampaignServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this Campaign.


        :param user_status: The user_status of this Campaign.  # noqa: E501
        :type: CampaignServiceUserStatus
        """

        self._user_status = user_status

    @property
    def viewable_frequency_cap(self):
        """Gets the viewable_frequency_cap of this Campaign.  # noqa: E501


        :return: The viewable_frequency_cap of this Campaign.  # noqa: E501
        :rtype: CampaignServiceViewableFrequencyCap
        """
        return self._viewable_frequency_cap

    @viewable_frequency_cap.setter
    def viewable_frequency_cap(self, viewable_frequency_cap):
        """Sets the viewable_frequency_cap of this Campaign.


        :param viewable_frequency_cap: The viewable_frequency_cap of this Campaign.  # noqa: E501
        :type: CampaignServiceViewableFrequencyCap
        """

        self._viewable_frequency_cap = viewable_frequency_cap

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Campaign):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Campaign):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroupAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad': 'AdGroupAdServiceAd',
        'ad_group_id': 'int',
        'ad_group_name': 'str',
        'ad_id': 'int',
        'ad_name': 'str',
        'ad_style': 'AdGroupAdServiceAdStyle',
        'approval_status': 'AdGroupAdServiceApprovalStatus',
        'bid': 'AdGroupAdServiceBid',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'disapproval_reason_codes': 'list[str]',
        'impression_beacon_urls': 'list[str]',
        'is_remove_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_third_party_tracking_script_url': 'AdGroupAdServiceIsRemoveFlg',
        'labels': 'list[AdGroupAdServiceLabel]',
        'media_id': 'int',
        'third_party_tracking_script_url': 'str',
        'third_party_tracking_vendor': 'str',
        'user_status': 'AdGroupAdServiceUserStatus'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad': 'ad',
        'ad_group_id': 'adGroupId',
        'ad_group_name': 'adGroupName',
        'ad_id': 'adId',
        'ad_name': 'adName',
        'ad_style': 'adStyle',
        'approval_status': 'approvalStatus',
        'bid': 'bid',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'impression_beacon_urls': 'impressionBeaconUrls',
        'is_remove_beacon_urls': 'isRemoveBeaconUrls',
        'is_remove_third_party_tracking_script_url': 'isRemoveThirdPartyTrackingScriptUrl',
        'labels': 'labels',
        'media_id': 'mediaId',
        'third_party_tracking_script_url': 'thirdPartyTrackingScriptUrl',
        'third_party_tracking_vendor': 'thirdPartyTrackingVendor',
        'user_status': 'userStatus'
    }

    def __init__(self, account_id=None, ad=None, ad_group_id=None, ad_group_name=None, ad_id=None, ad_name=None, ad_style=None, approval_status=None, bid=None, campaign_id=None, campaign_name=None, disapproval_reason_codes=None, impression_beacon_urls=None, is_remove_beacon_urls=None, is_remove_third_party_tracking_script_url=None, labels=None, media_id=None, third_party_tracking_script_url=None, third_party_tracking_vendor=None, user_status=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad = None
        self._ad_group_id = None
        self._ad_group_name = None
        self._ad_id = None
        self._ad_name = None
        self._ad_style = None
        self._approval_status = None
        self._bid = None
        self._campaign_id = None
        self._campaign_name = None
        self._disapproval_reason_codes = None
        self._impression_beacon_urls = None
        self._is_remove_beacon_urls = None
        self._is_remove_third_party_tracking_script_url = None
        self._labels = None
        self._media_id = None
        self._third_party_tracking_script_url = None
        self._third_party_tracking_vendor = None
        self._user_status = None
        self.discriminator = None

        self.account_id = account_id
        self.ad = ad
        self.ad_group_id = ad_group_id
        self.ad_group_name = ad_group_name
        self.ad_id = ad_id
        self.ad_name = ad_name
        self.ad_style = ad_style
        self.approval_status = approval_status
        self.bid = bid
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.disapproval_reason_codes = disapproval_reason_codes
        self.impression_beacon_urls = impression_beacon_urls
        self.is_remove_beacon_urls = is_remove_beacon_urls
        self.is_remove_third_party_tracking_script_url = is_remove_third_party_tracking_script_url
        self.labels = labels
        self.media_id = media_id
        self.third_party_tracking_script_url = third_party_tracking_script_url
        self.third_party_tracking_vendor = third_party_tracking_vendor
        self.user_status = user_status

    @property
    def account_id(self):
        """Gets the account_id of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The account_id of this AdGroupAd.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AdGroupAd.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :param account_id: The account_id of this AdGroupAd.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def ad(self):
        """Gets the ad of this AdGroupAd.  # noqa: E501


        :return: The ad of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceAd
        """
        return self._ad

    @ad.setter
    def ad(self, ad):
        """Sets the ad of this AdGroupAd.


        :param ad: The ad of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceAd
        """

        self._ad = ad

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 広告グループIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Ad group ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The ad_group_id of this AdGroupAd.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this AdGroupAd.

        <div lang=\"ja\"> 広告グループIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Ad group ID.<br> This field is required in requests. </div>   # noqa: E501

        :param ad_group_id: The ad_group_id of this AdGroupAd.  # noqa: E501
        :type: int
        """

        self._ad_group_id = ad_group_id

    @property
    def ad_group_name(self):
        """Gets the ad_group_name of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 広告グループ名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Ad group name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The ad_group_name of this AdGroupAd.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_name

    @ad_group_name.setter
    def ad_group_name(self, ad_group_name):
        """Sets the ad_group_name of this AdGroupAd.

        <div lang=\"ja\"> 広告グループ名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Ad group name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param ad_group_name: The ad_group_name of this AdGroupAd.  # noqa: E501
        :type: str
        """

        self._ad_group_name = ad_group_name

    @property
    def ad_id(self):
        """Gets the ad_id of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 広告IDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時に必須となります。 </div> <div lang=\"en\"> Ad ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation. </div>   # noqa: E501

        :return: The ad_id of this AdGroupAd.  # noqa: E501
        :rtype: int
        """
        return self._ad_id

    @ad_id.setter
    def ad_id(self, ad_id):
        """Sets the ad_id of this AdGroupAd.

        <div lang=\"ja\"> 広告IDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時に必須となります。 </div> <div lang=\"en\"> Ad ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation. </div>   # noqa: E501

        :param ad_id: The ad_id of this AdGroupAd.  # noqa: E501
        :type: int
        """

        self._ad_id = ad_id

    @property
    def ad_name(self):
        """Gets the ad_name of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 広告名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The ad_name of this AdGroupAd.  # noqa: E501
        :rtype: str
        """
        return self._ad_name

    @ad_name.setter
    def ad_name(self, ad_name):
        """Sets the ad_name of this AdGroupAd.

        <div lang=\"ja\"> 広告名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param ad_name: The ad_name of this AdGroupAd.  # noqa: E501
        :type: str
        """

        self._ad_name = ad_name

    @property
    def ad_style(self):
        """Gets the ad_style of this AdGroupAd.  # noqa: E501


        :return: The ad_style of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceAdStyle
        """
        return self._ad_style

    @ad_style.setter
    def ad_style(self, ad_style):
        """Sets the ad_style of this AdGroupAd.


        :param ad_style: The ad_style of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceAdStyle
        """

        self._ad_style = ad_style

    @property
    def approval_status(self):
        """Gets the approval_status of this AdGroupAd.  # noqa: E501


        :return: The approval_status of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this AdGroupAd.


        :param approval_status: The approval_status of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def bid(self):
        """Gets the bid of this AdGroupAd.  # noqa: E501


        :return: The bid of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceBid
        """
        return self._bid

    @bid.setter
    def bid(self, bid):
        """Sets the bid of this AdGroupAd.


        :param bid: The bid of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceBid
        """

        self._bid = bid

    @property
    def campaign_id(self):
        """Gets the campaign_id of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The campaign_id of this AdGroupAd.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this AdGroupAd.

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in requests. </div>   # noqa: E501

        :param campaign_id: The campaign_id of this AdGroupAd.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Campaign name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The campaign_name of this AdGroupAd.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this AdGroupAd.

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Campaign name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param campaign_name: The campaign_name of this AdGroupAd.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 掲載拒否の理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The disapproval_reason_codes of this AdGroupAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this AdGroupAd.

        <div lang=\"ja\"> 掲載拒否の理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this AdGroupAd.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def impression_beacon_urls(self):
        """Gets the impression_beacon_urls of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> インプレッションビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Impression beacon URL.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The impression_beacon_urls of this AdGroupAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._impression_beacon_urls

    @impression_beacon_urls.setter
    def impression_beacon_urls(self, impression_beacon_urls):
        """Sets the impression_beacon_urls of this AdGroupAd.

        <div lang=\"ja\"> インプレッションビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Impression beacon URL.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param impression_beacon_urls: The impression_beacon_urls of this AdGroupAd.  # noqa: E501
        :type: list[str]
        """

        self._impression_beacon_urls = impression_beacon_urls

    @property
    def is_remove_beacon_urls(self):
        """Gets the is_remove_beacon_urls of this AdGroupAd.  # noqa: E501


        :return: The is_remove_beacon_urls of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_beacon_urls

    @is_remove_beacon_urls.setter
    def is_remove_beacon_urls(self, is_remove_beacon_urls):
        """Sets the is_remove_beacon_urls of this AdGroupAd.


        :param is_remove_beacon_urls: The is_remove_beacon_urls of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_beacon_urls = is_remove_beacon_urls

    @property
    def is_remove_third_party_tracking_script_url(self):
        """Gets the is_remove_third_party_tracking_script_url of this AdGroupAd.  # noqa: E501


        :return: The is_remove_third_party_tracking_script_url of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_third_party_tracking_script_url

    @is_remove_third_party_tracking_script_url.setter
    def is_remove_third_party_tracking_script_url(self, is_remove_third_party_tracking_script_url):
        """Sets the is_remove_third_party_tracking_script_url of this AdGroupAd.


        :param is_remove_third_party_tracking_script_url: The is_remove_third_party_tracking_script_url of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_third_party_tracking_script_url = is_remove_third_party_tracking_script_url

    @property
    def labels(self):
        """Gets the labels of this AdGroupAd.  # noqa: E501


        :return: The labels of this AdGroupAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdGroupAd.


        :param labels: The labels of this AdGroupAd.  # noqa: E501
        :type: list[AdGroupAdServiceLabel]
        """

        self._labels = labels

    @property
    def media_id(self):
        """Gets the media_id of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> メディアIDです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Media ID.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The media_id of this AdGroupAd.  # noqa: E501
        :rtype: int
        """
        return self._media_id

    @media_id.setter
    def media_id(self, media_id):
        """Sets the media_id of this AdGroupAd.

        <div lang=\"ja\"> メディアIDです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Media ID.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param media_id: The media_id of this AdGroupAd.  # noqa: E501
        :type: int
        """

        self._media_id = media_id

    @property
    def third_party_tracking_script_url(self):
        """Gets the third_party_tracking_script_url of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 第三者計測スクリプトURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Third party tracking script URL.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The third_party_tracking_script_url of this AdGroupAd.  # noqa: E501
        :rtype: str
        """
        return self._third_party_tracking_script_url

    @third_party_tracking_script_url.setter
    def third_party_tracking_script_url(self, third_party_tracking_script_url):
        """Sets the third_party_tracking_script_url of this AdGroupAd.

        <div lang=\"ja\"> 第三者計測スクリプトURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Third party tracking script URL.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param third_party_tracking_script_url: The third_party_tracking_script_url of this AdGroupAd.  # noqa: E501
        :type: str
        """

        self._third_party_tracking_script_url = third_party_tracking_script_url

    @property
    def third_party_tracking_vendor(self):
        """Gets the third_party_tracking_vendor of this AdGroupAd.  # noqa: E501

        <div lang=\"ja\"> 第三者計測ベンダー（ReadOnly）です。<br> thirdPartyTrackingScriptUrlのドメインに基づく第三者計測ベンダーが設定されます。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Third party tracking vendor (Read only).<br> Third party tracking vendor based on domain of thirdPartyTrackingScriptUrl is set.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The third_party_tracking_vendor of this AdGroupAd.  # noqa: E501
        :rtype: str
        """
        return self._third_party_tracking_vendor

    @third_party_tracking_vendor.setter
    def third_party_tracking_vendor(self, third_party_tracking_vendor):
        """Sets the third_party_tracking_vendor of this AdGroupAd.

        <div lang=\"ja\"> 第三者計測ベンダー（ReadOnly）です。<br> thirdPartyTrackingScriptUrlのドメインに基づく第三者計測ベンダーが設定されます。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Third party tracking vendor (Read only).<br> Third party tracking vendor based on domain of thirdPartyTrackingScriptUrl is set.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param third_party_tracking_vendor: The third_party_tracking_vendor of this AdGroupAd.  # noqa: E501
        :type: str
        """

        self._third_party_tracking_vendor = third_party_tracking_vendor

    @property
    def user_status(self):
        """Gets the user_status of this AdGroupAd.  # noqa: E501


        :return: The user_status of this AdGroupAd.  # noqa: E501
        :rtype: AdGroupAdServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroupAd.


        :param user_status: The user_status of this AdGroupAd.  # noqa: E501
        :type: AdGroupAdServiceUserStatus
        """

        self._user_status = user_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad_group_bidding_strategy': 'AdGroupServiceBiddingStrategy',
        'ad_group_id': 'int',
        'ad_group_name': 'str',
        'bid': 'AdGroupServiceBid',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'conversion_optimizer': 'AdGroupServiceConversionOptimizer',
        'device': 'list[AdGroupServiceDeviceType]',
        'device_app': 'list[AdGroupServiceDeviceAppType]',
        'device_os': 'list[AdGroupServiceDeviceOsType]',
        'device_os_version': 'str',
        'dynamic_image_extensions': 'AdGroupServiceDynamicImageExtensions',
        'feed_set_id': 'int',
        'is_remove_feed_set_id': 'bool',
        'labels': 'list[AdGroupServiceLabel]',
        'smart_device_carriers': 'list[AdGroupServiceSmartDeviceCarrier]',
        'user_status': 'AdGroupServiceUserStatus'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad_group_bidding_strategy': 'adGroupBiddingStrategy',
        'ad_group_id': 'adGroupId',
        'ad_group_name': 'adGroupName',
        'bid': 'bid',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'conversion_optimizer': 'conversionOptimizer',
        'device': 'device',
        'device_app': 'deviceApp',
        'device_os': 'deviceOs',
        'device_os_version': 'deviceOsVersion',
        'dynamic_image_extensions': 'dynamicImageExtensions',
        'feed_set_id': 'feedSetId',
        'is_remove_feed_set_id': 'isRemoveFeedSetId',
        'labels': 'labels',
        'smart_device_carriers': 'smartDeviceCarriers',
        'user_status': 'userStatus'
    }

    def __init__(self, account_id=None, ad_group_bidding_strategy=None, ad_group_id=None, ad_group_name=None, bid=None, campaign_id=None, campaign_name=None, conversion_optimizer=None, device=None, device_app=None, device_os=None, device_os_version=None, dynamic_image_extensions=None, feed_set_id=None, is_remove_feed_set_id=None, labels=None, smart_device_carriers=None, user_status=None, local_vars_configuration=None):  # noqa: E501
        """AdGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad_group_bidding_strategy = None
        self._ad_group_id = None
        self._ad_group_name = None
        self._bid = None
        self._campaign_id = None
        self._campaign_name = None
        self._conversion_optimizer = None
        self._device = None
        self._device_app = None
        self._device_os = None
        self._device_os_version = None
        self._dynamic_image_extensions = None
        self._feed_set_id = None
        self._is_remove_feed_set_id = None
        self._labels = None
        self._smart_device_carriers = None
        self._user_status = None
        self.discriminator = None

        self.account_id = account_id
        self.ad_group_bidding_strategy = ad_group_bidding_strategy
        self.ad_group_id = ad_group_id
        self.ad_group_name = ad_group_name
        self.bid = bid
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.conversion_optimizer = conversion_optimizer
        self.device = device
        self.device_app = device_app
        self.device_os = device_os
        self.device_os_version = device_os_version
        self.dynamic_image_extensions = dynamic_image_extensions
        self.feed_set_id = feed_set_id
        self.is_remove_feed_set_id = is_remove_feed_set_id
        self.labels = labels
        self.smart_device_carriers = smart_device_carriers
        self.user_status = user_status

    @property
    def account_id(self):
        """Gets the account_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The account_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AdGroup.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :param account_id: The account_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def ad_group_bidding_strategy(self):
        """Gets the ad_group_bidding_strategy of this AdGroup.  # noqa: E501


        :return: The ad_group_bidding_strategy of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceBiddingStrategy
        """
        return self._ad_group_bidding_strategy

    @ad_group_bidding_strategy.setter
    def ad_group_bidding_strategy(self, ad_group_bidding_strategy):
        """Sets the ad_group_bidding_strategy of this AdGroup.


        :param ad_group_bidding_strategy: The ad_group_bidding_strategy of this AdGroup.  # noqa: E501
        :type: AdGroupServiceBiddingStrategy
        """

        self._ad_group_bidding_strategy = ad_group_bidding_strategy

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> 広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。 </div> <div lang=\"en\"> Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation. </div>   # noqa: E501

        :return: The ad_group_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this AdGroup.

        <div lang=\"ja\"> 広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。 </div> <div lang=\"en\"> Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation. </div>   # noqa: E501

        :param ad_group_id: The ad_group_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._ad_group_id = ad_group_id

    @property
    def ad_group_name(self):
        """Gets the ad_group_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> 広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The ad_group_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_name

    @ad_group_name.setter
    def ad_group_name(self, ad_group_name):
        """Sets the ad_group_name of this AdGroup.

        <div lang=\"ja\"> 広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param ad_group_name: The ad_group_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._ad_group_name = ad_group_name

    @property
    def bid(self):
        """Gets the bid of this AdGroup.  # noqa: E501


        :return: The bid of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceBid
        """
        return self._bid

    @bid.setter
    def bid(self, bid):
        """Sets the bid of this AdGroup.


        :param bid: The bid of this AdGroup.  # noqa: E501
        :type: AdGroupServiceBid
        """

        self._bid = bid

    @property
    def campaign_id(self):
        """Gets the campaign_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The campaign_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this AdGroup.

        <div lang=\"ja\"> キャンペーンIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Campaign ID.<br> This field is required in requests. </div>   # noqa: E501

        :param campaign_id: The campaign_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Campaign name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The campaign_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this AdGroup.

        <div lang=\"ja\"> キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Campaign name.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param campaign_name: The campaign_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def conversion_optimizer(self):
        """Gets the conversion_optimizer of this AdGroup.  # noqa: E501


        :return: The conversion_optimizer of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceConversionOptimizer
        """
        return self._conversion_optimizer

    @conversion_optimizer.setter
    def conversion_optimizer(self, conversion_optimizer):
        """Sets the conversion_optimizer of this AdGroup.


        :param conversion_optimizer: The conversion_optimizer of this AdGroup.  # noqa: E501
        :type: AdGroupServiceConversionOptimizer
        """

        self._conversion_optimizer = conversion_optimizer

    @property
    def device(self):
        """Gets the device of this AdGroup.  # noqa: E501


        :return: The device of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceDeviceType]
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this AdGroup.


        :param device: The device of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceDeviceType]
        """

        self._device = device

    @property
    def device_app(self):
        """Gets the device_app of this AdGroup.  # noqa: E501


        :return: The device_app of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceDeviceAppType]
        """
        return self._device_app

    @device_app.setter
    def device_app(self, device_app):
        """Sets the device_app of this AdGroup.


        :param device_app: The device_app of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceDeviceAppType]
        """

        self._device_app = device_app

    @property
    def device_os(self):
        """Gets the device_os of this AdGroup.  # noqa: E501


        :return: The device_os of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceDeviceOsType]
        """
        return self._device_os

    @device_os.setter
    def device_os(self, device_os):
        """Sets the device_os of this AdGroup.


        :param device_os: The device_os of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceDeviceOsType]
        """

        self._device_os = device_os

    @property
    def device_os_version(self):
        """Gets the device_os_version of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> OSバージョンです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※設定を解除する場合は、NONEを設定してください。 </div> <div lang=\"en\"> OS version.<br> ∗To cancel the setting, specify &#34;NONE&#34;.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The device_os_version of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._device_os_version

    @device_os_version.setter
    def device_os_version(self, device_os_version):
        """Sets the device_os_version of this AdGroup.

        <div lang=\"ja\"> OSバージョンです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※設定を解除する場合は、NONEを設定してください。 </div> <div lang=\"en\"> OS version.<br> ∗To cancel the setting, specify &#34;NONE&#34;.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param device_os_version: The device_os_version of this AdGroup.  # noqa: E501
        :type: str
        """

        self._device_os_version = device_os_version

    @property
    def dynamic_image_extensions(self):
        """Gets the dynamic_image_extensions of this AdGroup.  # noqa: E501


        :return: The dynamic_image_extensions of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceDynamicImageExtensions
        """
        return self._dynamic_image_extensions

    @dynamic_image_extensions.setter
    def dynamic_image_extensions(self, dynamic_image_extensions):
        """Sets the dynamic_image_extensions of this AdGroup.


        :param dynamic_image_extensions: The dynamic_image_extensions of this AdGroup.  # noqa: E501
        :type: AdGroupServiceDynamicImageExtensions
        """

        self._dynamic_image_extensions = dynamic_image_extensions

    @property
    def feed_set_id(self):
        """Gets the feed_set_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> 商品セットIDです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> *ADD時に未指定の場合、デフォルトセットを自動で関連付けます。 </div> <div lang=\"en\"> Feed set ID.<br> This field is optional in ADD and SET operation.<br> * If feedSetId is not specified in ADD operation, the default set is associated automatically. </div>   # noqa: E501

        :return: The feed_set_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._feed_set_id

    @feed_set_id.setter
    def feed_set_id(self, feed_set_id):
        """Sets the feed_set_id of this AdGroup.

        <div lang=\"ja\"> 商品セットIDです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> *ADD時に未指定の場合、デフォルトセットを自動で関連付けます。 </div> <div lang=\"en\"> Feed set ID.<br> This field is optional in ADD and SET operation.<br> * If feedSetId is not specified in ADD operation, the default set is associated automatically. </div>   # noqa: E501

        :param feed_set_id: The feed_set_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._feed_set_id = feed_set_id

    @property
    def is_remove_feed_set_id(self):
        """Gets the is_remove_feed_set_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\"> 商品セットとの関連付けを削除します。<br> このフィールドは、リクエストの際には無視されます。<br> *商品セットの関連付けが必須となったため、この機能は廃止しました。 </div> <div lang=\"en\"> Remove association with feed set. (Stop delivery)<br> This field will be ignored on input.<br> * Association with feed set changed to required, so this feature was abolished. </div>   # noqa: E501

        :return: The is_remove_feed_set_id of this AdGroup.  # noqa: E501
        :rtype: bool
        """
        return self._is_remove_feed_set_id

    @is_remove_feed_set_id.setter
    def is_remove_feed_set_id(self, is_remove_feed_set_id):
        """Sets the is_remove_feed_set_id of this AdGroup.

        <div lang=\"ja\"> 商品セットとの関連付けを削除します。<br> このフィールドは、リクエストの際には無視されます。<br> *商品セットの関連付けが必須となったため、この機能は廃止しました。 </div> <div lang=\"en\"> Remove association with feed set. (Stop delivery)<br> This field will be ignored on input.<br> * Association with feed set changed to required, so this feature was abolished. </div>   # noqa: E501

        :param is_remove_feed_set_id: The is_remove_feed_set_id of this AdGroup.  # noqa: E501
        :type: bool
        """

        self._is_remove_feed_set_id = is_remove_feed_set_id

    @property
    def labels(self):
        """Gets the labels of this AdGroup.  # noqa: E501


        :return: The labels of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdGroup.


        :param labels: The labels of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceLabel]
        """

        self._labels = labels

    @property
    def smart_device_carriers(self):
        """Gets the smart_device_carriers of this AdGroup.  # noqa: E501


        :return: The smart_device_carriers of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceSmartDeviceCarrier]
        """
        return self._smart_device_carriers

    @smart_device_carriers.setter
    def smart_device_carriers(self, smart_device_carriers):
        """Sets the smart_device_carriers of this AdGroup.


        :param smart_device_carriers: The smart_device_carriers of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceSmartDeviceCarrier]
        """

        self._smart_device_carriers = smart_device_carriers

    @property
    def user_status(self):
        """Gets the user_status of this AdGroup.  # noqa: E501


        :return: The user_status of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroup.


        :param user_status: The user_status of this AdGroup.  # noqa: E501
        :type: AdGroupServiceUserStatus
        """

        self._user_status = user_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroup):
            return True

        return self.to_dict() != other.to_dict()
